Documentation
¶
Index ¶
- func Assist(args []string, prms ...AssistParameters) error
- func Build(args []string, prms ...BuildParameters) error
- func CachePackage(src, dst string) error
- func CheckGnuPG() error
- func CloneOrPullDir(outw, errw io.Writer, repo string) (string, error)
- func EjectLastPathArg(s string) string
- func Export(o io.Writer, e io.Writer) error
- func FilterFilenames(filenames []string, pkg string) ([]string, error)
- func Fix() error
- func FlutterTemplate() error
- func GnuPGidentity() (string, error)
- func GoCliTemplate() error
- func Push(args []string, prms ...PushParameters) error
- func Query(args []string, prms ...QueryParameters) error
- func Remove(args []string, prms ...RemoveParameters) error
- func Sync(args []string, prms ...SyncParameters) error
- func ValidateGitUser() error
- func ValidatePackager() error
- type AssistParameters
- type BuildParameters
- type PackageMetadata
- type PushParameters
- type QueryParameters
- type RemoveParameters
- type SyncParameters
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Assist ¶
func Assist(args []string, prms ...AssistParameters) error
func Build ¶
func Build(args []string, prms ...BuildParameters) error
Build package in current directory with provided arguements.
func CachePackage ¶
Move package and signature files to cache location defined by user.
func CheckGnuPG ¶
func CheckGnuPG() error
Ensure, that user have created gnupg keys for package signing before package is built and cached.
func CloneOrPullDir ¶
This function will clone provided repository to cache directory and return name of that directory.
func EjectLastPathArg ¶
Eject last name from directory or link.
func FilterFilenames ¶
Filter filenames related to required package.
func FlutterTemplate ¶
func FlutterTemplate() error
Function generates project template for flutter desktop application based on current directory name and identity in GnuPG.
func GnuPGidentity ¶
Returns name and email from GnuPG. Error, if did not succeed.
func GoCliTemplate ¶
func GoCliTemplate() error
Function generates project template for go cli utility based on current directory name and identity in GnuPG.
func Query ¶
func Query(args []string, prms ...QueryParameters) error
func Remove ¶
func Remove(args []string, prms ...RemoveParameters) error
func Sync ¶
func Sync(args []string, prms ...SyncParameters) error
Syncronize provided packages with provided parameters.
func ValidateGitUser ¶
func ValidateGitUser() error
func ValidatePackager ¶
func ValidatePackager() error
Validate, that packager defined in /etc/makepkg.conf matches signer authority in GnuPG.
Types ¶
type AssistParameters ¶
type AssistParameters struct {
Stdout io.Writer
Stderr io.Writer
Stdin io.Reader
// Export existing GnuPG key armored string.
Export bool
// Check compatability of identities across git, gpg and makepkg.
Fix bool
// Generate flutter template.
Flutter bool
// Generate go cli utility template.
Gocli bool
}
Parameters for util.
type BuildParameters ¶
type BuildParameters struct {
Stdout io.Writer
Stderr io.Writer
Stdin io.Reader
// Directory where resulting package and signature will be moved.
Dir string
// Do not ask for any confirmation on build/installation.
Quick bool
// Syncronize/reinstall package after build.
Syncbuild bool
// Remove dependencies after successful build.
Rmdeps bool
// Do not clean workspace before and after build.
Garbage bool
}
Parameters that can be used to build packages.
type PackageMetadata ¶
type PushParameters ¶
type PushParameters struct {
Stdout io.Writer
Stderr io.Writer
Stdin io.Reader
// Directory to read package files and signatures.
Directory string
// Which protocol to use for connection.
Insecure bool
// Custom distribution for which package is built.
Distro string
}
Parameters that will be used to execute push command.
type QueryParameters ¶
type QueryParameters struct {
Stdout io.Writer
Stderr io.Writer
Stdin io.Reader
// List outdated packages.
Outdated bool
// Get information about package.
Info []bool
// List package files.
List []bool
}
Parameters that will be used to execute push command.
type RemoveParameters ¶
type RemoveParameters struct {
Stdout io.Writer
Stderr io.Writer
Stdin io.Reader
// Ask for confirmation when deleting package.
Confirm bool
// Leave package dependencies in the system (removed by default).
Norecursive bool
// Leave package configs in the system (removed by default).
Nocfgs bool
// Remove packages and all packages that depend on them.
Cascade bool
// Use insecure connection for remote deletions.
Insecure bool
}
type SyncParameters ¶
type SyncParameters struct {
Stdout io.Writer
Stderr io.Writer
Stdin io.Reader
// Download fresh package databases from the server (-yy force)
Refresh []bool
// Upgrade installed packages (-uu enables downgrade)
Upgrade []bool
// Don't ask for any confirmation (--noconfirm)
Quick bool
// Reinstall up to date targets
Force bool
// Use HTTP instead of https
Insecure bool
}